#property copyright "Uniano"
#property link      "http://uniano.com"
#property version   "1.00"
#property indicator_chart_window
#property strict
#property indicator_buffers 1
#property indicator_plots   1
//-----------------------------------------------------------------------------------------------------------------------------------------------
   // External variables

input int               Distance         = 20;                      // Distance from high/low in points
input string            Comment0         = "Resistance settings:";  // ..................................................
input color             ResistanceColor  = clrRed;                  // Resistance line color
input int               ResistanceWidth  = 1;                       // Resistance line width
input ENUM_LINE_STYLE   ResistanceStyle  = STYLE_SOLID;             // Resistance line style
input string            Comment1         = "Support settings:";     // ..................................................
input color             SupportColor     = clrGreen;                // Support line color
input int               SupportWidth     = 1;                       // Support line width
input ENUM_LINE_STYLE   SupportStyle     = STYLE_SOLID;             // Support line style
//-----------------------------------------------------------------------------------------------------------------------------------------------
   // Global variables
   
double buffer[];    
//-----------------------------------------------------------------------------------------------------------------------------------------------
   // Initialization

int OnInit()
{
   SetIndexBuffer(0, buffer);
   
	return(INIT_SUCCEEDED);
}
//-----------------------------------------------------------------------------------------------------------------------------------------------
   // Deinitialization
   
void OnDeinit(const int reason)
{
   ObjectsDeleteAll(0,-1,OBJ_TRENDBYANGLE);
}
//-----------------------------------------------------------------------------------------------------------------------------------------------
   // Processing

int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
{
   ArraySetAsSeries(high,true);
   ArraySetAsSeries(low,true);
   ArraySetAsSeries(close,true);
   ArraySetAsSeries(open,true);
   
   int limit = rates_total - prev_calculated;
   
   if(prev_calculated==0)
   { 
      limit = (int)ChartGetInteger(ChartID(),CHART_VISIBLE_BARS)+100;
      PlotIndexSetInteger(0,PLOT_DRAW_BEGIN,rates_total-limit);
      PlotIndexSetInteger(1,PLOT_DRAW_BEGIN,rates_total-limit);
   }
   
   for(int i=limit;i>=0 && !IsStopped();i--)
   {
      string namebuy    = (string)iTime(Symbol(),PERIOD_CURRENT,i)+"BUY_GREEN";
      string namesell   = (string)iTime(Symbol(),PERIOD_CURRENT,i)+"SELL_RED";
      datetime current  = iTime(Symbol(),PERIOD_CURRENT,i);
      datetime previous = (current-PeriodSeconds());
      datetime next     = (current+PeriodSeconds());
      
      if(high[i]==low[i] || high[i]==0 || low[i]==0)
      {
         double highlevel = 0;
         double lowlevel  = 0;
         
         for(int b = i; b<=Bars(Symbol(),PERIOD_CURRENT)-10;b++)
         {
            if(high[b+1]!=low[b+1])
            {
               highlevel = high[b+1];
               lowlevel  = low[b+1];
               break;
            }
         }
         
         // Resistance
         if(ObjectFind(0,namesell)<0)
            ObjectCreate(0,namesell,OBJ_TRENDBYANGLE,0,previous,highlevel+(Distance*Point()),next,highlevel+(Distance*Point()));
         ObjectSetDouble(0,namesell,OBJPROP_ANGLE,0); 
         ObjectSetDouble(0,namesell,OBJPROP_PRICE,0,highlevel+(Distance*Point()));
         ObjectSetDouble(0,namesell,OBJPROP_PRICE,1,highlevel+(Distance*Point()));
         
         ObjectSetInteger(0,namesell,OBJPROP_COLOR,ResistanceColor); 
         ObjectSetInteger(0,namesell,OBJPROP_STYLE,ResistanceStyle); 
         ObjectSetInteger(0,namesell,OBJPROP_WIDTH,ResistanceWidth); 
         
         // Support
         if(ObjectFind(0,namebuy)<0)
            ObjectCreate(0,namebuy,OBJ_TRENDBYANGLE,0,previous,lowlevel-(Distance*Point()),next,lowlevel-(Distance*Point()));
         ObjectSetDouble(0,namebuy,OBJPROP_ANGLE,0); 
         ObjectSetDouble(0,namebuy,OBJPROP_PRICE,0,lowlevel-(Distance*Point()));
         ObjectSetDouble(0,namebuy,OBJPROP_PRICE,1,lowlevel-(Distance*Point()));
         ObjectSetInteger(0,namebuy,OBJPROP_COLOR,SupportColor); 
         ObjectSetInteger(0,namebuy,OBJPROP_STYLE,SupportStyle); 
         ObjectSetInteger(0,namebuy,OBJPROP_WIDTH,SupportWidth); 
      }
     
      if(high[i]!=low[i])
      {
         // Resistance
         if(ObjectFind(0,namesell)<0)
            ObjectCreate(0,namesell,OBJ_TRENDBYANGLE,0,previous,high[i]+(Distance*Point()),next,high[i]+(Distance*Point()));
         ObjectSetDouble(0,namesell,OBJPROP_ANGLE,0); 
         ObjectSetDouble(0,namesell,OBJPROP_PRICE,0,high[i]+(Distance*Point()));
         ObjectSetDouble(0,namesell,OBJPROP_PRICE,1,high[i]+(Distance*Point()));
         
         ObjectSetInteger(0,namesell,OBJPROP_COLOR,ResistanceColor); 
         ObjectSetInteger(0,namesell,OBJPROP_STYLE,ResistanceStyle); 
         ObjectSetInteger(0,namesell,OBJPROP_WIDTH,ResistanceWidth); 
         
         // Support
         if(ObjectFind(0,namebuy)<0)
            ObjectCreate(0,namebuy,OBJ_TRENDBYANGLE,0,previous,low[i]-(Distance*Point()),next,low[i]-(Distance*Point()));
         ObjectSetDouble(0,namebuy,OBJPROP_ANGLE,0); 
         ObjectSetDouble(0,namebuy,OBJPROP_PRICE,0,low[i]-(Distance*Point()));
         ObjectSetDouble(0,namebuy,OBJPROP_PRICE,1,low[i]-(Distance*Point()));
         ObjectSetInteger(0,namebuy,OBJPROP_COLOR,SupportColor); 
         ObjectSetInteger(0,namebuy,OBJPROP_STYLE,SupportStyle); 
         ObjectSetInteger(0,namebuy,OBJPROP_WIDTH,SupportWidth); 
      }
   }
   
  return(rates_total);
}
//-----------------------------------------------------------------------------------------------------------------------------------------------
